@@ -5,12 +5,14 @@ Created on Sun Dec 12 2021
 (C) 2021, Rohde&Schwarz, ramian
 """
 
+import struct
+import re
+import rskfd
+
 def ConvertIiQq2Wv():
     '''
     Test
     '''
-    import rskfd
-
     fs = 320e6
     data = rskfd.ReadIqw( r'\\Rsint.net\data\MU\SATURN\GROUP\GR_1E\TRANSFER\Reichert\signal\higher_qams.iiqq', iqiq=False)
     rskfd.WriteWv( data, fs, r'\\Rsint.net\data\MU\SATURN\GROUP\GR_1E\TRANSFER\Reichert\signal\higher_qams_DEC.wv')
@@ -23,12 +25,21 @@ def ReadFile( filename):
     '''
     Test
     '''
-    import rskfd
-
     data,fs = rskfd.ReadWv( filename)
     print( f'RMS power in file: {rskfd.MeanPower( data)} dBm, peak power: {rskfd.MeanPower( data)} dBm.\n')
     rskfd.WriteWv( data, fs, 'myfilename.wv')
 
+
+
+def ReadWvTest():
+    '''
+    Test the wv reading routine (tags!!)
+    '''
+    iq, fs = rskfd.ReadWv(r'C:\Users\ramian\Documents\gitlab\demo files\DirectDPD.wv')
+    iq, fs = rskfd.ReadWv(r'C:\Users\ramian\Documents\gitlab\demo files\IQ_d.wv')
+
+
 if __name__ == "__main__":
-	# ReadFile( r'awgn_20kHz.wv')
-    ConvertIiQq2Wv()
\ No newline at end of file
+	pass
+    # ReadWvTest()
+    
\ No newline at end of file
