@@ -276,12 +276,12 @@ def ReadWv( FileName, ReadData = True):
         SamplingRate = float( res.group("SamplingRate"))
     else:
         SamplingRate = NaN
-    res = re.search("LEVEL OFFS[ ]*:[ ]*(?P<RMSLevelOffset>[0-9]*.[0-9]*)[ ]*}",tags)
+    res = re.search("LEVEL OFFS[ ]*:[ ]*(?P<RMSLevelOffset>[0-9]*.?[0-9]*),",tags)
     if res:
         RmsLevelOffset = float( res.group("RMSLevelOffset"))
     else:
         RmsLevelOffset = NaN
-    res = re.search("COMMENT:Signal generated for SMx RMS level[ ]*:[ ]*(?P<RfRmsLevel>[0-9]*.[0-9]*)[ ]*}",tags)
+    res = re.search("Signal generated for SMx RMS level[ ]*:[ ]*(?P<RfRmsLevel>-?[0-9]*.?[0-9]*)[ ]*",tags)
     if res:
         RfRmsLevel = float( res.group("RfRmsLevel"))
     else:
