@@ -6,7 +6,9 @@ Created on Tue Feb 19 15:02:17 2019
 """
 
 from enum import Enum
+import ipaddress
 import math
+from operator import truediv
 import socket
 import logging
 import struct
@@ -105,6 +107,17 @@ class instrument(object):
         return self.__Options
 
 
+    def IsLocalHost(self):
+        '''
+        Return boolean true when instrument runs on localhost (e.g. VSE)
+        '''
+        if self.__ipaddress.lower().find('localhost') >= 0 | self.__ipaddress.lower().find('127.0.0.1'):
+            # missing check for same IP address
+            return True
+        else:
+            return False
+
+
     def SetTimeout( self, timeout):
         '''
         Set the timeout for the connection (non blocking socket).
